# Copilot Library (CopiI⪜)&trade;

Build smart applications powered by __Conversational Copilots__.

Please stay tuned for more information.

> THIS PROJECT IS IN ACTIVE DEVELOPMENT. PLEASE CHECK BACK LATER!

---

[![Test](https://github.com/alywonder/copilib/actions/workflows/run-tests.yml/badge.svg)](https://github.com/alywonder/copilib/actions/workflows/run-tests.yml)
[![Python](https://img.shields.io/badge/python-3.10%7C3.11-blue)](https://www.python.org/downloads/release/python-3100/)

---
<span style="font-size:8pt;">Copyright &copy; 2024 Weavers @ Eternal Loom. All rights reserved.</span>